/*
 * Copyright (c) 2002-2011, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.stock.business;

import fr.paris.lutece.plugins.stock.service.StockPlugin;

import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;


/**
 * This class provides Data Access methods for Person objects
 * @param <K> the primary key
 * @param <T> the ticket product
 * @param <F> the filter
 * @param <T_> the ticket product metamodel
 */
public class AbstractTicketProductDAO<K, T extends TicketProduct, F extends TicketProductFilter, T_ extends TicketProduct_>
    extends AbstractProductDAO<K, T, F, T_> implements ITicketProductDAO<K, T, F>
{
    /**
    *
    *{@inheritDoc}
    */
    @Override
    public String getPluginName(  )
    {
        return StockPlugin.PLUGIN_NAME;
    }

    /**
     * Build the predicate list from filter
     * @param filter the filter
     * @param root the product root
     * @param builder the criteria builder
     * @return the predicate list
     */
    @Override
    protected List<Predicate> buildPredicates( F filter, Root<T> root, CriteriaBuilder builder )
    {
        List<Predicate> listPredicates = super.buildPredicates( filter, root, builder );

        //the date end of the ticket can be null is this is a one session ticket
        if ( filter.getDateBegin(  ) != null )
        {
            listPredicates.add( builder.or( builder.greaterThanOrEqualTo( root.get( TicketProduct_.dateEnd ),
                        filter.getDateBegin(  ) ), builder.isNull( root.get( TicketProduct_.dateEnd ) ) ) );
        }

        if ( filter.getDateEnd(  ) != null )
        {
            listPredicates.add( builder.lessThanOrEqualTo( root.get( TicketProduct_.dateBegin ), filter.getDateEnd(  ) ) );
        }

        return listPredicates;
    }
}
