/*
 * Copyright (c) 2002-2011, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.stock.business;

import java.sql.Timestamp;

import java.util.List;

import javax.persistence.CollectionTable;
import javax.persistence.Column;
import javax.persistence.ElementCollection;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.Table;


/**
 * TicketProduct
 *
 *
 */
@Entity
@Table( name = "stock_ticket_product" )
public class TicketProduct extends Product
{
    private Timestamp _dateBegin;
    private Timestamp _dateEnd;
    private Timestamp _hour;
    private int _duration;
    private List<WeekDaysEnum> _weekDays;

    /**
     * Constructor
     */
    public TicketProduct(  )
    {
        super(  );
    }

    /**
     * Constructor from an other product
     * @param product the product
     */
    public TicketProduct( Product product )
    {
        super( product );
    }

    /**
     * Return the date begin
     * @return the date begin
     */
    @Column( name = "date_begin" )
    public Timestamp getDateBegin(  )
    {
        return _dateBegin;
    }

    /**
     * Set the date begin
     * @param dateBegin the date begin
     */
    public void setDateBegin( Timestamp dateBegin )
    {
        _dateBegin = dateBegin;
    }

    /**
     * Get the date end
     * @return the date end
     */
    @Column( name = "date_end" )
    public Timestamp getDateEnd(  )
    {
        return _dateEnd;
    }

    /**
     * Set date end
     * @param dateEnd the date end
     */
    public void setDateEnd( Timestamp dateEnd )
    {
        _dateEnd = dateEnd;
    }

    /**
     * Get the hour of the session
     * @return the hour (date with only the hour set)
     */
    @Column( name = "hour" )
    public Timestamp getHour(  )
    {
        return _hour;
    }

    /**
     * Set the hour of the session
     * @param hour (date with only the hour set)
     */
    public void setHour( Timestamp hour )
    {
        _hour = hour;
    }

    /**
     * Get Duration of the session
     * @return the duration of the session
     */
    @Column( name = "duration" )
    public int getDuration(  )
    {
        return _duration;
    }

    /**
     * Set the duration of the session
     * @param duration of the session
     */
    public void setDuration( int duration )
    {
        _duration = duration;
    }

    /**
     * Return the days when there is a session during the week
     * @return list of days
     */
    @ElementCollection( fetch = FetchType.EAGER )
    @CollectionTable( name = "stock_days" )
    @Column( name = "day" )
    @Enumerated( EnumType.STRING )
    public List<WeekDaysEnum> getDays(  )
    {
        return _weekDays;
    }

    /**
     * Set the days when there is a session during the week
     * @param days of week
     */
    public void setDays( List<WeekDaysEnum> days )
    {
        _weekDays = days;
    }
}
