/*
 * Copyright (c) 2002-2011, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.stock.business.order;

import fr.paris.lutece.plugins.stock.utils.jpa.StockJPAUtils;

import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.TableGenerator;


/**
 *
 * Basket
 *
 */
@Entity
@Table( name = "stock_basket" )
public class Basket
{
    /** Sequence name */
    private static final String JPA_SEQUENCE_NAME = "stock_basket_sequence";

    /** Unique value */
    private static final String JPA_COLUMN_NAME = "stock_basket_id";
    private List<Item> _itemList;
    private boolean _validated;
    private int _nIdUser;
    private int _nIdBasket;

    /**
     * Return the item ordered
     * @return item list
     */
    @OneToMany( cascade = CascadeType.ALL, fetch = FetchType.LAZY, mappedBy = "basket" )
    public List<Item> getItemList(  )
    {
        return _itemList;
    }

    /**
     * Set the item ordered
     * @param itemList  items ordered
     */
    public void setItemList( List<Item> itemList )
    {
        _itemList = itemList;
    }

    /**
     * Return true if the basket is validated by the user
     * @return true if the basket is validated
     */
    @Column( name = "validated" )
    public boolean isValidated(  )
    {
        return _validated;
    }

    /**
     * Validate the order
     * @param validated the boolean
     */
    public void setValidated( boolean validated )
    {
        _validated = validated;
    }

    /**
     * Get the user id
     * @return the user id
     */
    @Column( name = "id_user" )
    public int getIdUser(  )
    {
        return _nIdUser;
    }

    /**
     * Set the user id
     * @param nIdUser the user id
     */
    public void setIdUser( int nIdUser )
    {
        _nIdUser = nIdUser;
    }

    /**
     * Return the basket id
     * @return the basket id
     */
    @TableGenerator( table = StockJPAUtils.SEQUENCE_TABLE_NAME, name = JPA_SEQUENCE_NAME, pkColumnValue = JPA_COLUMN_NAME, allocationSize = 1 )
    @Id
    @GeneratedValue( strategy = GenerationType.TABLE, generator = JPA_SEQUENCE_NAME )
    @Column( name = "id_basket" )
    public int getIdBasket(  )
    {
        return _nIdBasket;
    }

    /**
     * Set the basket id
     * @param nIdBasket the basket id
     */
    public void setIdBasket( int nIdBasket )
    {
        _nIdBasket = nIdBasket;
    }
}
