/*
 * Copyright (c) 2002-2011, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.stock.business.order;

import fr.paris.lutece.plugins.stock.utils.jpa.StockJPAUtils;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.TableGenerator;


/**
 *
 * Item
 *
 */
@Entity
@Table( name = "stock_item" )
public class Item
{
    /** Sequence name */
    private static final String JPA_SEQUENCE_NAME = "stock_item_sequence";

    /** Unique value */
    private static final String JPA_COLUMN_NAME = "stock_item_id";
    private int _nIdItem;
    private int _quantity;
    private String _summary;
    private float _price;
    private int _nIdProduct;
    private Basket _basket;

    /**
     * Return the item id
     * @return the item id
     */
    @TableGenerator( table = StockJPAUtils.SEQUENCE_TABLE_NAME, name = JPA_SEQUENCE_NAME, pkColumnValue = JPA_COLUMN_NAME, allocationSize = 1 )
    @Id
    @GeneratedValue( strategy = GenerationType.TABLE, generator = JPA_SEQUENCE_NAME )
    @Column( name = "id_item" )
    public int getIdItem(  )
    {
        return _nIdItem;
    }

    /**
     * Set the item id
     * @param nIdItem the item id
     */
    public void setIdItem( int nIdItem )
    {
        _nIdItem = nIdItem;
    }

    /**
     * Get the basket where the item is set
     * @return basket
     */
    @ManyToOne( optional = false, fetch = FetchType.LAZY )
    @JoinColumn( name = "id_basket" )
    public Basket getBasket(  )
    {
        return _basket;
    }

    /**
     * Set the basket linked to the item
     * @param basket the basket
     */
    public void setBasket( Basket basket )
    {
        _basket = basket;
    }

    /**
     * Get the quantity ordered
     * @return the quantity ordered
     */
    @Column( name = "quantity" )
    public int getQuantity(  )
    {
        return _quantity;
    }

    /**
     * Set the quantity ordered
     * @param quantity the quantity ordered
     */
    public void setQuantity( int quantity )
    {
        _quantity = quantity;
    }

    /**
     * Get the summary of the product ordered
     * @return the summary
     */
    @Column( name = "summary" )
    public String getSummary(  )
    {
        return _summary;
    }

    /**
     * Set the summary
     * @param summary the summary
     */
    public void setSummary( String summary )
    {
        _summary = summary;
    }

    /**
     * Return the total price for product ordered in this item
     * @return the price
     */
    @Column( name = "price" )
    public float getPrice(  )
    {
        return _price;
    }

    /**
     * Set the price
     * @param price the price
     */
    public void setPrice( float price )
    {
        _price = price;
    }

    /**
     * Return the product id
     * @return the product id
     */
    @Column( name = "id_product" )
    public int getIdProduct(  )
    {
        return _nIdProduct;
    }

    /**
     * Set the product id
     * @param nIdProduct the new id of the product
     */
    public void setIdProduct( int nIdProduct )
    {
        _nIdProduct = nIdProduct;
    }
}
