/*
 * Copyright (c) 2002-2011, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.stock.service;

import fr.paris.lutece.portal.service.database.AppConnectionService;
import fr.paris.lutece.portal.service.plugin.PluginDefaultImplementation;
import fr.paris.lutece.portal.service.spring.SpringContextService;


/**
 * DocumentPlugin
 */
public class StockPlugin extends PluginDefaultImplementation
{
    public static final String PLUGIN_NAME = "stock";

    /**
     * {@inheritDoc}
     */
    @Override
    public void init(  )
    {
        super.init(  );

        if ( isInstalled(  ) )
        {
            initServices(  );
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void install(  )
    {
        super.install(  );

        initServices(  );
    }

    /**
     * Init all the global services
     */
    protected void initServices(  )
    {
        initProductServices(  );
        initProviderServices(  );
        initCategoryServices(  );
    }

    /**
     * Init the {@link GlobalProductService} class
     */
    private void initProductServices(  )
    {
        if ( !AppConnectionService.NO_POOL_DEFINED.equals( this.getDbPoolName(  ) ) )
        {
            IProductService productService = (IProductService) SpringContextService.getBean( "stock.productService" );
            IProductService ticketProductService = (IProductService) SpringContextService.getBean( 
                    "stock.ticketProductService" );

            productService.init(  );
            ticketProductService.init(  );

            GlobalProductService.getInstance(  ).register( productService );
            GlobalProductService.getInstance(  ).register( ticketProductService );
        }
    }

    /**
     * Init the {@link GlobalProviderService} class
     */
    private void initProviderServices(  )
    {
        if ( !AppConnectionService.NO_POOL_DEFINED.equals( this.getDbPoolName(  ) ) )
        {
            IProviderService providerService = (IProviderService) SpringContextService.getBean( "stock.providerService" );
            providerService.init(  );
            GlobalProviderService.getInstance(  ).register( providerService );
        }
    }

    /**
     * Init the {@link GlobalCategoryService} class
     */
    private void initCategoryServices(  )
    {
        if ( !AppConnectionService.NO_POOL_DEFINED.equals( this.getDbPoolName(  ) ) )
        {
            ICategoryService categoryService = (ICategoryService) SpringContextService.getBean( "stock.categoryService" );
            ICategoryService ticketCategoryService = (ICategoryService) SpringContextService.getBean( 
                    "stock.ticketCategoryService" );

            categoryService.init(  );
            ticketCategoryService.init(  );

            GlobalCategoryService.getInstance(  ).register( categoryService );
            GlobalCategoryService.getInstance(  ).register( ticketCategoryService );
        }
    }
}
