/*
 * Copyright (c) 2002-2011, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.stock.web;

import fr.paris.lutece.plugins.stock.business.Category;
import fr.paris.lutece.plugins.stock.business.ICategoryHome;
import fr.paris.lutece.plugins.stock.business.IProviderHome;
import fr.paris.lutece.plugins.stock.business.ObjectDefinition;
import fr.paris.lutece.plugins.stock.business.Provider;
import fr.paris.lutece.plugins.stock.business.ProviderFilter;
import fr.paris.lutece.plugins.stock.service.GlobalProviderService;
import fr.paris.lutece.plugins.stock.service.ProviderPermissionsService;
import fr.paris.lutece.plugins.stock.service.StockPlugin;
import fr.paris.lutece.plugins.stock.utils.constants.StockConstants;
import fr.paris.lutece.portal.service.message.AdminMessage;
import fr.paris.lutece.portal.service.message.AdminMessageService;
import fr.paris.lutece.portal.service.spring.SpringContextService;
import fr.paris.lutece.portal.service.template.AppTemplateService;
import fr.paris.lutece.portal.service.util.AppLogService;
import fr.paris.lutece.portal.service.util.AppPathService;
import fr.paris.lutece.portal.service.util.AppPropertiesService;
import fr.paris.lutece.portal.web.admin.PluginAdminPageJspBean;
import fr.paris.lutece.portal.web.constants.Messages;
import fr.paris.lutece.portal.web.constants.Parameters;
import fr.paris.lutece.portal.web.util.LocalizedPaginator;
import fr.paris.lutece.util.html.HtmlTemplate;
import fr.paris.lutece.util.html.Paginator;
import fr.paris.lutece.util.string.StringUtil;
import fr.paris.lutece.util.url.UrlItem;

import org.apache.commons.lang.StringUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;


/**
 * This class provides the user interface to manage form features ( manage,
 * create, modify, remove)
 */
public class ProviderJspBean extends PluginAdminPageJspBean
{
    public static final String RIGHT_MANAGE_PARTNERS = "PARTNERS_MANAGEMENT";
    public static final String PARAMETER_PROVIDER_ID = "provider_id";
    protected static final String PARAMETER_JSP = "jsp";
    protected static final String PROPERTY_DEFAULT_SESSION_PER_PAGE = "stock.itemsPerPage";
    protected static final String MARK_FILTER = "filter";
    protected static final String MARK_PAGINATOR = "paginator";
    protected static final String MARK_NB_ITEMS_PER_PAGE = "nb_items_per_page";
    private static final String PARAMETER_PROVIDER_NAME = "provider_name";
    private static final String PARAMETER_PROVIDER_CONTACT_NAME = "provider_contact_name";
    private static final String PARAMETER_PROVIDER_MAIL = "provider_mail";
    private static final String PARAMETER_PROVIDER_ADDRESS = "provider_address";
    private static final String PARAMETER_PROVIDER_PHONE_NUMBER = "provider_phone_number";
    private static final String PARAMETER_PROVIDER_COMMENT = "provider_comment";
    private static final String PROPERTY_PAGE_TITLE_CREATE_PROVIDER = "stock.create_provider.title";
    private static final String PROPERTY_PAGE_TITLE_MODIFY_PROVIDER = "stock.modify_provider.title";
    private static final String PROPERTY_PAGE_TITLE_MANAGE_PROVIDER = "stock.manage_stock.providers_management";
    private static final String PROPERTY_PAGE_TITLE_MANAGE_PROVIDER_CREATION = "stock.manage_provider_creation.pageTitle";
    private static final String PROPERTY_PAGE_TITLE_CHOOSE_PROVIDER_PRODUCT = "stock.choose_provider.pageTitle";
    private static final String TEMPLATE_MANAGE_PROVIDERS = "admin/plugins/stock/manage_providers.html";
    private static final String TEMPLATE_MANAGE_PROVIDERS_TYPES = "admin/plugins/stock/list_providers_types.html";
    private static final String TEMPLATE_MANAGE_PROVIDER_PRODUCTS = "admin/plugins/stock/manage_provider_products.html";
    private static final String TEMPLATE_CHOOSE_PROVIDER_PRODUCT = "admin/plugins/stock/choose_provider_of_product.html";
    private static final String PARAMETER_FILTER_NAME = "filter_name";
    private static final String PARAMETER_FILTER_CONTACT_NAME = "filter_contactName";
    private static final String PARAMETER_FILTER_PHONE_NUMBER = "filter_phoneNumber";
    private static final String PARAMETER_FILTER_ADDRESS = "filter_address";
    private static final String PARAMETER_FILTER_MAIL = "filter_mail";
    private static final String PARAMETER_FILTER = "filter";
    private static final String JSP_MANAGE_PROVIDERS = "jsp/admin/plugins/stock/ManageProviders.jsp";
    private static final String MARK_LIST_PROVIDERS = "list_providers";
    private static final String MARK_LIST_CATEGORIES = "list_categories";
    private static final String MARK_LIST_PROVIDER_OBJECT_DEFINITION = "list_provider_definition";
    private static final String MARK_GLOBAL_PROVIDER_SERVICE = "global_provider_service";
    private static final String MARK_CURRENT_USER = "current_user";
    private static final String MESSAGE_MESSAGE_EMAIL_FORMAT = "stock.message.email.format";
    private ProviderFilter _filter;
    private int _nDefaultItemsPerPage;
    private String _strCurrentPageIndex;
    private int _nItemsPerPage;
    private IProviderHome _homeProvider;
    private ICategoryHome _homeCategory;

    /**
     * Constructor
     */
    public ProviderJspBean(  )
    {
        super(  );
        _filter = new ProviderFilter(  );
        _homeProvider = (IProviderHome) SpringContextService.getPluginBean( StockPlugin.PLUGIN_NAME,
                "stock.providerHome" );
        _homeCategory = (ICategoryHome) SpringContextService.getPluginBean( StockPlugin.PLUGIN_NAME,
                "stock.categoryHome" );
    }

    /**
     * Fill the filter from the request
     * @param filter the filter
     * @param request the request
     */
    protected void buildFilter( ProviderFilter filter, HttpServletRequest request )
    {
        filter.setName( request.getParameter( PARAMETER_FILTER_NAME ) );
        filter.setContactName( request.getParameter( PARAMETER_FILTER_CONTACT_NAME ) );
        filter.setMail( request.getParameter( PARAMETER_FILTER_MAIL ) );
        filter.setPhoneNumber( request.getParameter( PARAMETER_FILTER_PHONE_NUMBER ) );
        filter.setAddress( request.getParameter( PARAMETER_FILTER_ADDRESS ) );
    }

    /**
     * Gets the filter from request.
     * If {@link #PARAMETER_FILTER} found in request, then build new filter.
     * Return session one otherwise.
     * @param request the request
     * @return the filter
     */
    private ProviderFilter getProviderFilter( HttpServletRequest request )
    {
        // SORT
        String strSortedAttributeName = request.getParameter( Parameters.SORTED_ATTRIBUTE_NAME );

        // "filter" in request  ==> new filter. use old one otherwise
        if ( request.getParameter( PARAMETER_FILTER ) != null )
        {
            ProviderFilter filter = new ProviderFilter(  );
            buildFilter( filter, request );
            _filter = filter;
        }

        if ( strSortedAttributeName != null )
        {
            _filter.setOrder( strSortedAttributeName );

            String strAscSort = request.getParameter( Parameters.SORTED_ASC );

            boolean bIsAscSort = Boolean.parseBoolean( strAscSort );
            _filter.setOrderAsc( bIsAscSort );
        }

        return _filter;
    }

    /**
     * Return the Html code for the management page of providers
     * @param request The Http request
     * @return the Html code for the management page of providers
     */
    public String getManageProviders( HttpServletRequest request )
    {
        setPageTitleProperty( getMangagePageTitle(  ) );

        _strCurrentPageIndex = Paginator.getPageIndex( request, Paginator.PARAMETER_PAGE_INDEX, _strCurrentPageIndex );
        _nDefaultItemsPerPage = AppPropertiesService.getPropertyInt( PROPERTY_DEFAULT_SESSION_PER_PAGE, 50 );
        _nItemsPerPage = Paginator.getItemsPerPage( request, Paginator.PARAMETER_ITEMS_PER_PAGE, _nItemsPerPage,
                _nDefaultItemsPerPage );

        ProviderFilter filter = getProviderFilter( request );
        filter.setProducts( true );

        List<Provider> listProviders = _homeProvider.findByFilter( filter );

        Paginator<Provider> paginator = new LocalizedPaginator<Provider>( listProviders, _nItemsPerPage,
                getJspManageProvider( request ), Paginator.PARAMETER_PAGE_INDEX, _strCurrentPageIndex, getLocale(  ) );

        Map<String, Object> model = new HashMap<String, Object>(  );

        // put the paginator informations
        model.put( MARK_NB_ITEMS_PER_PAGE, "" + _nItemsPerPage );
        model.put( MARK_PAGINATOR, paginator );
        model.put( MARK_LIST_PROVIDERS, paginator.getPageItems(  ) );
        model.put( MARK_FILTER, filter );
        model.put( StockConstants.MARK_JSP_BACK, getRelativeJspManageProvider( request ) );

        // put the GlobalProviderService and the current AdminUser to know what
        // actions he can do 
        model.put( MARK_GLOBAL_PROVIDER_SERVICE, GlobalProviderService.getInstance(  ) );
        model.put( MARK_CURRENT_USER, getUser(  ) );

        HtmlTemplate template = AppTemplateService.getTemplate( TEMPLATE_MANAGE_PROVIDERS, getLocale(  ), model );

        return getAdminPage( template.getHtml(  ) );
    }

    /**
     * Return the Html code for choosing the provider type to create
     * @param request The Http request
     * @return the Html code for choosing the provider type to create
     */
    public String getManageCreationProvider( HttpServletRequest request )
    {
        setPageTitleProperty( PROPERTY_PAGE_TITLE_MANAGE_PROVIDER_CREATION );

        List<ObjectDefinition> listObjectDefinitions = GlobalProviderService.getInstance(  )
                                                                            .getAuthorizedObjectDefinitionForCreation( getUser(  ) );
        Map<String, Object> model = new HashMap<String, Object>(  );

        model.put( MARK_LIST_PROVIDER_OBJECT_DEFINITION, listObjectDefinitions );
        model.put( StockConstants.MARK_JSP_BACK, request.getParameter( StockConstants.MARK_JSP_BACK ) );

        HtmlTemplate template = AppTemplateService.getTemplate( TEMPLATE_MANAGE_PROVIDERS_TYPES, getLocale(  ), model );

        return getAdminPage( template.getHtml(  ) );
    }

    /**
     * Return management page of a provider's products
     * @param request The Http request
     * @return Html management page of plugin stock
     */
    public String getManageProviderProducts( HttpServletRequest request )
    {
        setPageTitleProperty( PROPERTY_PAGE_TITLE_MANAGE_PROVIDER );

        // Get The provider to display his products
        Integer idProvider = getIdProvider( request );

        if ( idProvider == null )
        {
            return AdminMessageService.getMessageUrl( request, StockConstants.MESSAGE_ERROR_OCCUR,
                AdminMessage.TYPE_STOP );
        }

        Provider provider = _homeProvider.findByIdWithProducts( idProvider );

        _strCurrentPageIndex = Paginator.getPageIndex( request, Paginator.PARAMETER_PAGE_INDEX, _strCurrentPageIndex );
        _nDefaultItemsPerPage = AppPropertiesService.getPropertyInt( PROPERTY_DEFAULT_SESSION_PER_PAGE, 50 );
        _nItemsPerPage = Paginator.getItemsPerPage( request, Paginator.PARAMETER_ITEMS_PER_PAGE, _nItemsPerPage,
                _nDefaultItemsPerPage );

        List<Category> listCategoriesWithProducts = new ArrayList<Category>(  );

        for ( Category category : provider.getProducts(  ) )
        {
            // Loads the products of the category 
            category = _homeCategory.findByIdWithProduct( category.getIdCategory(  ) );
            listCategoriesWithProducts.add( category );
        }

        Paginator<Category> paginator = new LocalizedPaginator<Category>( listCategoriesWithProducts, _nItemsPerPage,
                getJspManageProvider( request ), Paginator.PARAMETER_PAGE_INDEX, _strCurrentPageIndex, getLocale(  ) );

        Map<String, Object> model = new HashMap<String, Object>(  );
        addPermissions( model, request );
        model.put( MARK_NB_ITEMS_PER_PAGE, "" + _nItemsPerPage );
        model.put( MARK_PAGINATOR, paginator );
        model.put( MARK_LIST_CATEGORIES, paginator.getPageItems(  ) );

        HtmlTemplate template = AppTemplateService.getTemplate( TEMPLATE_MANAGE_PROVIDER_PRODUCTS, getLocale(  ), model );

        return getAdminPage( template.getHtml(  ) );
    }

    /**
     * Returns the form to create a provider
     *
     * @param request The Http request
     * @param strProviderClassName The class name of the provider entity to create
     * @return the html code of the provider form
     */
    public String getCreateProvider( HttpServletRequest request, String strProviderClassName )
    {
        if ( !GlobalProviderService.getInstance(  ).isAuthorizedToCreate( getUser(  ), strProviderClassName ) )
        {
            return getManageProviders( request );
        }

        setPageTitleProperty( getCreatePageTitle(  ) );

        Map<String, Object> model = new HashMap<String, Object>(  );
        // Add the JSP wich called this action
        model.put( StockConstants.MARK_JSP_BACK, request.getParameter( StockConstants.MARK_JSP_BACK ) );
        addPermissions( model, request );
        GlobalProviderService.getInstance(  ).initModelForCreation( strProviderClassName, model );

        String strTemplateName = GlobalProviderService.getInstance(  ).getCreateTemplate( strProviderClassName );

        HtmlTemplate template = AppTemplateService.getTemplate( strTemplateName, getLocale(  ), model );

        return getAdminPage( template.getHtml(  ) );
    }

    /**
     * Process the data capture form of a new provider
     * @param request The Http Request
     * @param strProviderClassName The class name of the provider entity to create
     * @return The Jsp URL of the process result
     */
    public String doCreateProvider( HttpServletRequest request, String strProviderClassName )
    {
        String strCancel = request.getParameter( StockConstants.PARAMETER_BUTTON_CANCEL );

        if ( !GlobalProviderService.getInstance(  ).isAuthorizedToCreate( getUser(  ), strProviderClassName ) ||
                StringUtils.isNotBlank( strCancel ) )
        {
            return doGoBack( request );
        }

        String strProviderName = request.getParameter( PARAMETER_PROVIDER_NAME );
        String strProviderAddress = request.getParameter( PARAMETER_PROVIDER_ADDRESS );
        String strProviderContactName = request.getParameter( PARAMETER_PROVIDER_CONTACT_NAME );
        String strProviderMail = request.getParameter( PARAMETER_PROVIDER_MAIL );
        String strProviderPhoneNumber = request.getParameter( PARAMETER_PROVIDER_PHONE_NUMBER );
        String strProviderComment = request.getParameter( PARAMETER_PROVIDER_COMMENT );

        // Controls mandatory fields
        String strMandatoryFieldsError = null;

        if ( ( strProviderName == null ) || strProviderName.equals( StockConstants.EMPTY_STRING ) )
        {
            strMandatoryFieldsError = Messages.MANDATORY_FIELDS;
        }

        if ( ( strMandatoryFieldsError != null ) && StringUtils.isNotBlank( strProviderMail ) &&
                !StringUtil.checkEmail( strProviderMail ) )
        {
            strMandatoryFieldsError = MESSAGE_MESSAGE_EMAIL_FORMAT;
        }

        try
        {
            if ( ( strMandatoryFieldsError != null ) && StringUtils.isNotBlank( strProviderPhoneNumber ) )
            {
                Long.valueOf( strProviderPhoneNumber );
            }
        }
        catch ( NumberFormatException e )
        {
            // The phone number is found but is not a number
            AppLogService.error( e );
            strMandatoryFieldsError = StockConstants.MESSAGE_ERROR_PHONE_NUMBER_FORMAT;
        }

        if ( strMandatoryFieldsError != null )
        {
            return AdminMessageService.getMessageUrl( request, strMandatoryFieldsError, AdminMessage.TYPE_STOP );
        }

        Provider provider = new Provider(  );
        provider.setName( strProviderName );
        provider.setContactName( strProviderContactName );
        provider.setAddress( strProviderAddress );
        provider.setMail( strProviderMail );
        provider.setPhoneNumber( strProviderPhoneNumber );
        provider.setComment( strProviderComment );

        try
        {
            GlobalProviderService.getInstance(  ).doCreateProvider( strProviderClassName, provider, request );
        }
        catch ( RuntimeException e )
        {
            return AdminMessageService.getMessageUrl( request, e.getMessage(  ), AdminMessage.TYPE_STOP );
        }

        return doGoBack( request );
    }

    /**
     * Returns the form to modify a provider
     *
     * @param request The Http request
     * @param strProviderClassName The class name of the provider entity to modify
     * @return the html code of the provider form
     */
    public String getModifyProvider( HttpServletRequest request, String strProviderClassName )
    {
        if ( !GlobalProviderService.getInstance(  ).isAuthorizedToModify( getUser(  ), strProviderClassName ) )
        {
            return getManageProviders( request );
        }

        setPageTitleProperty( getModifyPageTitle(  ) );

        String strProviderId = request.getParameter( PARAMETER_PROVIDER_ID );
        int nIdProvider;

        try
        {
            nIdProvider = Integer.parseInt( strProviderId );
        }
        catch ( NumberFormatException e )
        {
            AppLogService.debug( e );

            return AdminMessageService.getMessageUrl( request, StockConstants.MESSAGE_ERROR_OCCUR,
                    AdminMessage.TYPE_STOP );
        }

        Map<String, Object> model = new HashMap<String, Object>(  );
        model.put( StockConstants.MARK_JSP_BACK, request.getParameter( StockConstants.MARK_JSP_BACK ) );
        addPermissions( model, request );
        GlobalProviderService.getInstance(  ).initModelForModification( strProviderClassName, nIdProvider, model );

        String strTemplateName = GlobalProviderService.getInstance(  ).getModifyTemplate( strProviderClassName );

        HtmlTemplate template = AppTemplateService.getTemplate( strTemplateName, getLocale(  ), model );

        return getAdminPage( template.getHtml(  ) );
    }

    /**
     * Return the url of the JSP which called the last action
     * @param request The Http request
     * @return The url of the last JSP
     */
    private String doGoBack( HttpServletRequest request )
    {
        String strJspBack = request.getParameter( StockConstants.MARK_JSP_BACK );

        return StringUtils.isNotBlank( strJspBack ) ? ( AppPathService.getBaseUrl( request ) + strJspBack )
                                                    : getJspManageProvider( request );
    }

    /**
     * Process the data capture form of a provider
     *
     * @param request The Http Request
     * @param strProviderClassName The class name of the provider entity to modify
     * @return The Jsp URL of the process result
     */
    public String doModifyProvider( HttpServletRequest request, String strProviderClassName )
    {
        String strCancel = request.getParameter( StockConstants.PARAMETER_BUTTON_CANCEL );

        if ( !GlobalProviderService.getInstance(  ).isAuthorizedToModify( getUser(  ), strProviderClassName ) ||
                StringUtils.isNotBlank( strCancel ) )
        {
            return doGoBack( request );
        }

        String strProviderId = request.getParameter( PARAMETER_PROVIDER_ID );
        String strProviderName = request.getParameter( PARAMETER_PROVIDER_NAME );
        String strProviderAddress = request.getParameter( PARAMETER_PROVIDER_ADDRESS );
        String strProviderContactName = request.getParameter( PARAMETER_PROVIDER_CONTACT_NAME );
        String strProviderMail = request.getParameter( PARAMETER_PROVIDER_MAIL );
        String strProviderPhoneNumber = request.getParameter( PARAMETER_PROVIDER_PHONE_NUMBER );
        String strProviderComment = request.getParameter( PARAMETER_PROVIDER_COMMENT );

        // Controls mandatory fields
        String strError = null;
        int nIdProvider = StockConstants.UNDEFINED;

        try
        {
            nIdProvider = Integer.parseInt( strProviderId );
        }
        catch ( NumberFormatException e )
        {
            AppLogService.debug( e );
            strError = StockConstants.MESSAGE_ERROR_OCCUR;
        }

        if ( ( strProviderName == null ) || strProviderName.equals( StockConstants.EMPTY_STRING ) )
        {
            strError = Messages.MANDATORY_FIELDS;
        }

        try
        {
            if ( StringUtils.isNotBlank( strProviderPhoneNumber ) )
            {
                Long.valueOf( strProviderPhoneNumber );
            }
        }
        catch ( NumberFormatException e )
        {
            // The phone number is found but is not a number
            AppLogService.error( e );
            strError = StockConstants.MESSAGE_ERROR_PHONE_NUMBER_FORMAT;
        }

        if ( strError != null )
        {
            return AdminMessageService.getMessageUrl( request, strError, AdminMessage.TYPE_STOP );
        }

        Provider provider = new Provider(  );
        provider.setIdProvider( nIdProvider );
        provider.setName( strProviderName );
        provider.setContactName( strProviderContactName );
        provider.setAddress( strProviderAddress );
        provider.setMail( strProviderMail );
        provider.setPhoneNumber( strProviderPhoneNumber );
        provider.setComment( strProviderComment );

        try
        {
            GlobalProviderService.getInstance(  ).doModifyProvider( strProviderClassName, provider, request );
        }
        catch ( RuntimeException e )
        {
            return AdminMessageService.getMessageUrl( request, e.getMessage(  ), AdminMessage.TYPE_STOP );
        }

        return doGoBack( request );
    }

    /**
     * Returns the confirmation message to delete a provider
     *
     * @param request The Http request
     * @param strProviderClassName The class name of the provider entity to delete
     * @return the html code message
     */
    public String getDeleteProvider( HttpServletRequest request, String strProviderClassName )
    {
        if ( !GlobalProviderService.getInstance(  ).isAuthorizedToDelete( getUser(  ), strProviderClassName ) )
        {
            return getManageProviders( request );
        }

        String strProviderId = request.getParameter( PARAMETER_PROVIDER_ID );

        int nIdProvider;

        try
        {
            nIdProvider = Integer.parseInt( strProviderId );
        }
        catch ( NumberFormatException e )
        {
            AppLogService.debug( e );

            return AdminMessageService.getMessageUrl( request, StockConstants.MESSAGE_ERROR_OCCUR,
                AdminMessage.TYPE_STOP );
        }

        UrlItem url = new UrlItem( GlobalProviderService.getInstance(  ).getDeleteJsp( strProviderClassName ) );

        Map<String, Object> urlParam = new HashMap<String, Object>(  );
        urlParam.put( PARAMETER_PROVIDER_ID, nIdProvider );

        String strJspBack = request.getParameter( StockConstants.MARK_JSP_BACK );

        if ( StringUtils.isNotBlank( strJspBack ) )
        {
            urlParam.put( StockConstants.MARK_JSP_BACK, strJspBack );
        }

        return AdminMessageService.getMessageUrl( request, getDeleteMessage(  ), url.getUrl(  ),
            AdminMessage.TYPE_CONFIRMATION, urlParam );
    }

    /**
     * Delete a provider
     *
     * @param request The Http request
     * @param strProviderClassName The class name of the provider entity to delete
     * @return the html code message
     */
    public String doDeleteProvider( HttpServletRequest request, String strProviderClassName )
    {
        if ( !GlobalProviderService.getInstance(  ).isAuthorizedToDelete( getUser(  ), strProviderClassName ) )
        {
            return getManageProviders( request );
        }

        String strProviderId = request.getParameter( PARAMETER_PROVIDER_ID );

        int nIdProvider;

        try
        {
            nIdProvider = Integer.parseInt( strProviderId );
        }
        catch ( NumberFormatException e )
        {
            AppLogService.debug( e );

            return AdminMessageService.getMessageUrl( request, StockConstants.MESSAGE_ERROR_OCCUR,
                AdminMessage.TYPE_STOP );
        }

        GlobalProviderService.getInstance(  ).doDeleteProvider( strProviderClassName, nIdProvider );

        return doGoBack( request );
    }

    /**
     * return the provider id from the request
     * @param request the request
     * @return the provider id
     */
    private static Integer getIdProvider( HttpServletRequest request )
    {
        String strIdProvider = request.getParameter( PARAMETER_PROVIDER_ID );

        if ( strIdProvider != null )
        {
            return Integer.parseInt( strIdProvider );
        }

        return null;
    }

    /**
     * Returns the Html code for choosing the provider of the product to create
     * @param request The Http request
     * @return the Html code for choosing the provider of the product to create
     */
    public String getChooseProviderOfProduct( HttpServletRequest request )
    {
        setPageTitleProperty( PROPERTY_PAGE_TITLE_CHOOSE_PROVIDER_PRODUCT );

        _strCurrentPageIndex = Paginator.getPageIndex( request, Paginator.PARAMETER_PAGE_INDEX, _strCurrentPageIndex );
        _nDefaultItemsPerPage = AppPropertiesService.getPropertyInt( PROPERTY_DEFAULT_SESSION_PER_PAGE, 50 );
        _nItemsPerPage = Paginator.getItemsPerPage( request, Paginator.PARAMETER_ITEMS_PER_PAGE, _nItemsPerPage,
                _nDefaultItemsPerPage );

        ProviderFilter filter = getProviderFilter( request );

        List<Provider> listProviders = _homeProvider.findByFilter( filter );

        Paginator<Provider> paginator = new LocalizedPaginator<Provider>( listProviders, _nItemsPerPage,
                getJspManageProvider( request ), Paginator.PARAMETER_PAGE_INDEX, _strCurrentPageIndex, getLocale(  ) );

        Map<String, Object> model = new HashMap<String, Object>(  );

        model.put( MARK_NB_ITEMS_PER_PAGE, "" + _nItemsPerPage );
        model.put( MARK_PAGINATOR, paginator );
        model.put( MARK_LIST_PROVIDERS, paginator.getPageItems(  ) );
        model.put( MARK_FILTER, filter );

        String strJsp = request.getParameter( PARAMETER_JSP );
        model.put( PARAMETER_JSP, strJsp );
        // Category of the product to create
        model.put( StockJspBean.PARAMETER_CATEGORY_ID, request.getParameter( StockJspBean.PARAMETER_CATEGORY_ID ) );

        HtmlTemplate template = AppTemplateService.getTemplate( TEMPLATE_CHOOSE_PROVIDER_PRODUCT, getLocale(  ), model );

        return getAdminPage( template.getHtml(  ) );
    }

    /**
         * return url of the jsp manage provider
         * @param request The HTTP request
         * @return url of the jsp manage provider
         */
    protected String getJspManageProvider( HttpServletRequest request )
    {
        return AppPathService.getBaseUrl( request ) + JSP_MANAGE_PROVIDERS;
    }

    /**
     * return the url of the jsp manage provider. This url is not absolute.
     * @param request The HTTP request
     * @return the relative url of the jsp manage provider
     */
    protected String getRelativeJspManageProvider( HttpServletRequest request )
    {
        return JSP_MANAGE_PROVIDERS;
    }

    /**
     * return the message to display before deleting a provider
     * @return the message
     */
    protected String getDeleteMessage(  )
    {
        return StockConstants.MESSAGE_CONFIRMATION_DELETE_PROVIDER;
    }

    /**
     * Return the title of the providers management page
     * @return the title
     */
    protected String getMangagePageTitle(  )
    {
        return PROPERTY_PAGE_TITLE_MANAGE_PROVIDER;
    }

    /**
     * Return the title of the provider creation page
     * @return the title
     */
    protected String getCreatePageTitle(  )
    {
        return PROPERTY_PAGE_TITLE_CREATE_PROVIDER;
    }

    /**
     * Return the title of the provider modification page
     * @return the title
     */
    protected String getModifyPageTitle(  )
    {
        return PROPERTY_PAGE_TITLE_MODIFY_PROVIDER;
    }

    /**
    * Adds permissions into the model
    * @param model the model
    * @param request the request
    */
    protected void addPermissions( Map<String, Object> model, HttpServletRequest request )
    {
        ProviderPermissionsService.addPermissionToModel( model, getUser(  ) );
    }
}
